TEMPLATE = """# This file was auto-generated by Microwler

# Use this template as starting point for your new project.
# To find out more about configuration options, read the docs: https://innovinati.github.io/microwler


from microwler import Microwler, scrape, export


select = {
    # Add selectors here
    # Docs: https://innovinati.github.io/microwler/scraping/#selectors
}

settings = {
    # Add settings here
    # Docs: https://innovinati.github.io/microwler/configuration/#settings
}


def transform(data: dict):
    # Manipulate data here
    # Example: https://github.com/INNOVINATI/microwler/blob/master/test_cases.py#L54
    return data


# Microwler expects a variable "crawler" when running from CLI
crawler = Microwler(
    'START_URL',
    select=select,
    transform=transform,
    settings=settings
)
"""
