(window.webpackJsonp=window.webpackJsonp||[]).push([[4],{375:function(r,t,e){"use strict";e.r(t);var n={},o=e(68),c=e(98),v=e.n(c),l=e(378),_=e(323),d=e(317),h=e(372),w=e(368),m=e(313),component=Object(o.a)(n,(function(){var r=this,t=r.$createElement,e=r._self._c||t;return e("v-row",{attrs:{justify:"center",align:"center"}},[e("v-col",{staticClass:"text-center",attrs:{cols:"12",sm:"8",md:"6"}},[e("img",{attrs:{src:"logo.png",width:"200"}}),r._v(" "),e("v-card",[e("v-card-title",{staticClass:"headline"},[e("v-spacer"),r._v("\nWelcome to Microwler UI\n                    "),e("v-spacer")],1),r._v(" "),e("v-card-text",[e("p",[r._v("\n            This is a simple web client for your Microwler services.\n          ")]),r._v(" "),e("p",[r._v("\n            For more information on Microwler, check out the "),e("a",{attrs:{href:"https://innovinati.github.io/microwler",target:"_blank",rel:"noopener noreferrer"}},[r._v("\n              documentation\n            ")]),r._v(".\n          ")]),r._v(" "),e("p",[r._v("\n            Found a bug? Report it on the github "),e("a",{attrs:{href:"https://github.com/innovinati/microwler/issues",target:"_blank",rel:"noopener noreferrer",title:"contribute"}},[r._v("\n              issue board\n            ")]),r._v(".\n          ")]),r._v(" "),e("p",[r._v("Thank you for using Microwler!")]),r._v(" "),e("hr",{staticClass:"my-3"}),r._v(" "),e("a",{attrs:{href:"https://innovinati.com/",target:"_blank",rel:"noopener noreferrer"}},[r._v("\n            powered by INNOVINATI\n          ")])]),r._v(" "),e("v-card-actions",[e("v-spacer"),r._v(" "),e("v-btn",{attrs:{color:"primary",nuxt:"",to:"/connect"}},[r._v("\n            Start app\n          ")]),r._v(" "),e("v-spacer")],1)],1)],1)],1)}),[],!1,null,null,null);t.default=component.exports;v()(component,{VBtn:l.a,VCard:_.a,VCardActions:d.a,VCardText:d.c,VCardTitle:d.d,VCol:h.a,VRow:w.a,VSpacer:m.a})}}]);